<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Просмотр изображений Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Просмотр изображений Deepin является современным и гладким менеджером изображений.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Он имеет функции управления просмотра и редактирования основных изображений.</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>изображение</translation>
    </message>
    <message>
        <source>images</source>
        <translation>изображения</translation>
    </message>
    <message>
        <source>album</source>
        <translation>альбом</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>альбомы</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Управление синхронизацией</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Синхронизация:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Безымянный</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Недавно импортированные</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Избранное</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Вы уверены, что хотите удалить альбом?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Шкала времени</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Вы можете добавить каталог синхронизации или перетащить изображения на шкалу времени</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Безымянный</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Просмотр Изображений Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отменав</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Вы уверены, что хотите удалить альбом?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Синхронизировать и создать</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхронизировать</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Вы уверены, что добавили в список синхронизации и создали альбом, названный именем этой папки?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Успешно экспортированно</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Экспортировать не удалось</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Вы уверены, что хотите выбросить изображения в КОРЗИНУ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Этот файл содержит несколько страниц, пожалуйста используйте Evince для просмотра всех страниц.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный Экран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Распечатать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копировать в буфер обмена</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Выбросить в корзину</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Удалить из альбома</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Вращать по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Вращать против часовой стрелки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отобразить в менеджере файлов</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Вы можете добавить каталог синхронизации или перетащить изображения на шкалу времени</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Добавить альбом</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Добавить новый альбом</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Открыть каталог</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Вы не имеете прав на просмотр страницы</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Дата снимка</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата изменения</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Цветовое пространство</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим экспозиции</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Программа экспозиции</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Время экспозиции</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Вспышка</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Диафрагма</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокусное расстояние</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Макс диафрагма</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим замера экспозиции</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс белого</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компенсация вспышки</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модель камеры</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модель линзы</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Без масштабирования</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Подгонка страницы к изображению</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Подгонка изображения к странице</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Масштабировать до:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Миллиметры</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Сантиметры</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Дюймы</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Позиция Изображения</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Масштабирование</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Настройки Изображения</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Шторка</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Коммутатор</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Скользящий</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Кольцо</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Выбрать Каталог</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Этот каталог отключен от инхронизации</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Добавить папку</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Управление Синхронизацией Каталога</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Список каталогов пуст</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Отмена синхронизации</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Устройство было удалено</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Каталог больше не существует</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Рассчитываю...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Просмотр Изображений</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный Экран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Закончить показ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Выбросить в корзину</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Удалить из альбома</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отобразить в менеджере файлов</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Предыдущий экран</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Следующий экран</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показать сочетания</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Пожалуйста, введите новое сочетание</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Сочетания</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Просмотр изображения</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Восстановить значения по Умолчанию</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный Зкран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Закончить показ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Распечатать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Выбросить в корзину</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Удалить из альбома</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отобразить в менеджере файлов</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Закончить показ</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Пауза/Воспроизведение</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Настройки Показа</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Переключить эффекты</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Длительность включения</translation>
    </message>
    <message>
        <source>second</source>
        <translation>секунда</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Управление изображением</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Размер 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>По размеру окна</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Вращать против часовой стрелки</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Вращать по часовой стрелке</translation>
    </message>
    <message>
        <source>Throw to Trash</source>
        <translation>Выбросить в Корзину</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Изображение не найдено</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 изображение</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 изображения</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Управление синхронизацией</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Синхронизация:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Вы можете добавить каталог синхронизации или перетащить изображения на шкалу времени</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Добавить альбом</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Добавить новый альбом</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный Экран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Распечатать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копировать в буфер обмена</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Выбросить в корзину</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отобразить в менеджере файлов</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Настройки Показа</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Эффект</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Сочетания</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Недавно импортированные </translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Image Viewer - это современный и изящный менеджер изображений.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Он предназначен для управления, просмотра и редактирования изображениями начального уровня.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Темная тема</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Временная шкала</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Добавить в альбом</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Добавить новый альбом</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный Экран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Распечатать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копировать в буфер обмена</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Выбросить в корзину</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Удалить из альбома</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Показать меню навигации</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Скрыть меню навигации</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелке</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отобразить в менеджере файлов</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
</context>
</TS>